==> haskell-crypton-conduit-0.2.3-212-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-3EN5zse1H5T29qz3O5MqJq
key:                  crypton-conduit-0.2.3-3EN5zse1H5T29qz3O5MqJq
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  7cf6ce87d6fa75b948ac0fbf462b5dce
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-3EN5zse1H5T29qz3O5MqJq
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI exceptions-0.10.7
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-conduit-0.2.3-214-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-C3XT4NKKUAXEBDPgweQsL
key:                  crypton-conduit-0.2.3-C3XT4NKKUAXEBDPgweQsL
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  fb41bdd94f82c9a4842c298feff04571
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-C3XT4NKKUAXEBDPgweQsL
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G
    crypton-1.0.4-37TsNQoV8Vb5042LlXS4MC exceptions-0.10.7
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    resourcet-1.2.6-JtO0n9rtgTt543EMYn7K77 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
